@@ -195,7 +195,9 @@ def print_settings(settings):
 
     print("Settings:")
     if settings.get_is_nac():
-        print("  Non-analytical term correction: on")
+        print("  Non-analytical term correction (NAC): on")
+        if settings.get_nac_q_direction() is not None:
+            print("  NAC q-direction: %s" % settings.get_nac_q_direction())
     if settings.get_fc_spg_symmetry():
         print("  Enforce space group symmetry to force constants: on")
     if settings.get_fc_symmetry():
@@ -604,22 +606,6 @@ if run_mode == 'displacements':
 ########################################
 # Preparations for phonon calculations #
 ########################################
-if settings.get_read_force_constants():
-    phonon.set_force_constants(fc)
-elif os.path.exists("FORCE_SETS"):
-    phonon.set_displacement_dataset(force_sets)
-    if log_level > 0:
-        print("Computing force constants...")
-
-    if settings.get_fc_spg_symmetry():
-        # Need to calculate full force constant tensors
-        phonon.produce_force_constants(
-            computation_algorithm=settings.get_fc_computation_algorithm())
-    else: # Only force constants between atoms in primitive cell and supercell
-        phonon.produce_force_constants(
-            calculate_full_force_constants=False,
-            computation_algorithm=settings.get_fc_computation_algorithm())
-
 # Non-analytical term correction (LO-TO splitting)
 if settings.get_is_nac():
     if file_exists("BORN", log_level):
@@ -635,6 +621,8 @@ if settings.get_is_nac():
             sys.exit(1)
         if nac_params['factor'] == None:
             nac_params['factor'] = physical_units['nac_factor']
+        if settings.get_nac_method() is not None:
+            nac_params['method'] = settings.get_nac_method()
         phonon.set_nac_params(nac_params=nac_params)
 
         if log_level > 1:
@@ -652,6 +640,23 @@ if settings.get_is_nac():
                     print("%s %12.7f %12.7f %12.7f" % ((text,) + tuple(v)))
             print("-" * 76)
 
+# Force constants
+if settings.get_read_force_constants():
+    phonon.set_force_constants(fc)
+elif os.path.exists("FORCE_SETS"):
+    phonon.set_displacement_dataset(force_sets)
+    if log_level > 0:
+        print("Computing force constants...")
+
+    if settings.get_fc_spg_symmetry():
+        # Need to calculate full force constant tensors
+        phonon.produce_force_constants(
+            computation_algorithm=settings.get_fc_computation_algorithm())
+    else: # Only force constants between atoms in primitive cell and supercell
+        phonon.produce_force_constants(
+            calculate_full_force_constants=False,
+            computation_algorithm=settings.get_fc_computation_algorithm())
+
 # Impose cutoff radius on force constants
 cutoff_radius = settings.get_cutoff_radius()
 if cutoff_radius:
