@@ -53,7 +53,8 @@ class Settings(object):
         self._displacement_distance = None
         self._dm_decimals = None
         self._fc_decimals = None
-        self._fc_symmetry_iteration = 0
+        self._fc_symmetry = False
+        self._fpitch = None
         self._frequency_conversion_factor = None
         self._gv_delta_q = None
         self._is_diagonal_displacement = True
@@ -65,24 +66,22 @@ class Settings(object):
         self._is_symmetry = True
         self._is_tetrahedron_method = False
         self._is_time_reversal_symmetry = True
-        self._is_translational_symmetry = False
         self._is_trigonal_displacement = False
         self._magmoms = None
         self._masses = None
         self._mesh = None
         self._mesh_shift = None
-        self._fpitch = None
+        self._nac_method = None
+        self._nac_q_direction = None
         self._num_frequency_points = None
         self._primitive_matrix = None
         self._qpoints = None
-        self._q_direction = None
         self._read_qpoints = False
         self._sigma = None
         self._supercell_matrix = None
         self._tmax = 1000
         self._tmin = 0
         self._tstep = 10
-        self._tsym_type = 0
         self._yaml_mode = False
 
     def set_band_paths(self, band_paths):
@@ -133,11 +132,11 @@ class Settings(object):
     def get_displacement_distance(self):
         return self._displacement_distance
 
-    def set_fc_symmetry_iteration(self, iteration):
-        self._fc_symmetry_iteration = iteration
+    def set_fc_symmetry(self, fc_symmetry):
+        self._fc_symmetry = fc_symmetry
 
-    def get_fc_symmetry_iteration(self):
-        return self._fc_symmetry_iteration
+    def get_fc_symmetry(self):
+        return self._fc_symmetry
 
     def set_fc_decimals(self, decimals):
         self._fc_decimals = decimals
@@ -223,12 +222,6 @@ class Settings(object):
     def get_is_symmetry(self):
         return self._is_symmetry
 
-    def set_is_translational_symmetry(self, is_translational_symmetry):
-        self._is_translational_symmetry = is_translational_symmetry
-
-    def get_is_translational_symmetry(self):
-        return self._is_translational_symmetry
-
     def set_magnetic_moments(self, magmoms):
         self._magmoms = magmoms
 
@@ -265,11 +258,17 @@ class Settings(object):
     def get_min_temperature(self):
         return self._tmin
 
-    def set_nac_q_direction(self, q_direction):
-        self._q_direction = q_direction
+    def set_nac_method(self, nac_method):
+        self._nac_method = nac_method
+
+    def get_nac_method(self):
+        return self._nac_method
+
+    def set_nac_q_direction(self, nac_q_direction):
+        self._nac_q_direction = nac_q_direction
 
     def get_nac_q_direction(self):
-        return self._q_direction
+        return self._nac_q_direction
 
     def set_primitive_matrix(self, primitive_matrix):
         self._primitive_matrix = primitive_matrix
@@ -313,16 +312,6 @@ class Settings(object):
     def get_time_reversal_symmetry(self):
         return self._is_time_reversal_symmetry
 
-    # Translational symmetry type
-    # 0: No imposition
-    # 1: Simple sum, sum(fc) / N
-    # 2: Weighted sum, sum(fc) * abs(fc) / sum(abs(fc))
-    def set_tsym_type(self, tsym_type):
-        self._tsym_type = tsym_type
-
-    def get_tsym_type(self):
-        return self._tsym_type
-
     def set_yaml_mode(self, yaml_mode):
         self._yaml_mode = yaml_mode
 
@@ -414,7 +403,7 @@ class ConfParser(object):
 
         if 'fc_symmetry' in arg_list:
             if self._args.fc_symmetry:
-                self._confs['fc_symmetry'] = self._args.fc_symmetry
+                self._confs['fc_symmetry'] = '.true.'
 
         if 'force_constants_decimals' in arg_list:
             if self._args.force_constants_decimals:
@@ -445,14 +434,6 @@ class ConfParser(object):
             if self._args.is_nosym:
                 self._confs['symmetry'] = '.false.'
 
-        if 'is_translational_symmetry' in arg_list:
-            if self._args.is_translational_symmetry:
-                self._confs['translation'] = '.true.'
-
-        if 'tsym_type' in arg_list:
-            if self._args.tsym_type:
-                self._confs['tsym_type'] = self._args.tsym_type
-
         if 'is_plusminus_displacements' in arg_list:
             if self._args.is_plusminus_displacements:
                 self._confs['pm'] = '.true.'
@@ -503,9 +484,13 @@ class ConfParser(object):
             if self._args.qpoints is not None:
                 self._confs['qpoints'] = self._args.qpoints
 
-        if 'q_direction' in arg_list:
-            if self._args.q_direction is not None:
-                self._confs['q_direction'] = self._args.q_direction
+        if 'nac_q_direction' in arg_list:
+            if self._args.nac_q_direction is not None:
+                self._confs['q_direction'] = self._args.nac_q_direction
+
+        if 'nac_method' in arg_list:
+            if self._args.nac_method is not None:
+                self._confs['nac_method'] = self._args.nac_method
 
         if 'read_qpoints' in arg_list:
             if self._args.read_qpoints:
@@ -628,19 +613,16 @@ class ConfParser(object):
                 if confs['mesh_symmetry'].lower() == '.false.':
                     self.set_parameter('is_mesh_symmetry', False)
 
-            if conf_key == 'translation':
-                if confs['translation'].lower() == '.true.':
-                    self.set_parameter('is_translation', True)
-
-            if conf_key == 'tsym_type':
-                self.set_parameter('tsym_type', confs['tsym_type'])
-
             if conf_key == 'rotational':
                 if confs['rotational'].lower() == '.true.':
                     self.set_parameter('is_rotational', True)
 
             if conf_key == 'fc_symmetry':
-                self.set_parameter('fc_symmetry', confs['fc_symmetry'])
+                if confs['fc_symmetry'].lower() == '.true.':
+                    self.set_parameter('fc_symmetry', True)
+                else:
+                    self.setting_error(
+                        "FC_SYMMETRY has to be specified by .TRUE. or .FALSE.")
 
             if conf_key == 'fc_decimals':
                 self.set_parameter('fc_decimals', confs['fc_decimals'])
@@ -685,12 +667,15 @@ class ConfParser(object):
                 if confs['read_qpoints'].lower() == '.true.':
                     self.set_parameter('read_qpoints', True)
 
+            if conf_key == 'nac_method':
+                self.set_parameter('nac_method', confs['nac_method'].lower())
+
             if conf_key == 'q_direction':
                 q_direction = [fracval(x) for x in confs['q_direction'].split()]
                 if len(q_direction) < 3:
                     self.setting_error("Number of elements of q_direction is less than 3")
                 else:
-                    self.set_parameter('q_direction', q_direction)
+                    self.set_parameter('nac_q_direction', q_direction)
 
             if conf_key == 'frequency_conversion_factor':
                 val = float(confs['frequency_conversion_factor'])
@@ -784,7 +769,7 @@ class ConfParser(object):
         # Enforce translational invariance and index permutation symmetry
         # to force constants?
         if 'fc_symmetry' in params:
-            self._settings.set_fc_symmetry_iteration(int(params['fc_symmetry']))
+            self._settings.set_fc_symmetry(params['fc_symmetry'])
 
         # Frequency unit conversion factor
         if 'frequency_conversion_factor' in params:
@@ -832,11 +817,6 @@ class ConfParser(object):
             self._settings.set_is_tetrahedron_method(
                 params['is_tetrahedron_method'])
 
-        # Is translational invariance ?
-        if 'is_translation' in params:
-            self._settings.set_is_translational_symmetry(
-                params['is_translation'])
-
         # Trigonal displacement
         if 'is_trigonal_displacement' in params:
             self._settings.set_is_trigonal_displacement(
@@ -867,9 +847,13 @@ class ConfParser(object):
             if params['read_qpoints']:
                 self._settings.set_read_qpoints(params['read_qpoints'])
 
+        # non analytical term correction method
+        if 'nac_method' in params:
+            self._settings.set_nac_method(params['nac_method'])
+
         # q-direction for non analytical term correction
-        if 'q_direction' in params:
-            self._settings.set_nac_q_direction(params['q_direction'])
+        if 'nac_q_direction' in params:
+            self._settings.set_nac_q_direction(params['nac_q_direction'])
 
         # Smearing width
         if 'sigma' in params:
@@ -887,10 +871,6 @@ class ConfParser(object):
         if 'tstep' in params:
             self._settings.set_temperature_step(params['tstep'])
 
-        # Choice of imposing translational invariance
-        if 'tsym_type' in params:
-            self._settings.set_tsym_type(params['tsym_type'])
-
         # Band paths
         # BAND = 0.0 0.0 0.0  0.5 0.0 0.0  0.5 0.5 0.0  0.0 0.0 0.0  0.5 0.5 0.5
         # [array([[ 0. ,  0. ,  0. ],
@@ -934,8 +914,6 @@ class PhonopySettings(Settings):
         self._band_connection = False
         self._cutoff_radius = None
         self._dos = None
-        self._dos_range = {'min':  None,
-                           'max':  None}
         self._fc_computation_algorithm = "svd"
         self._fc_spg_symmetry = False
         self._fits_Debye_model = False
@@ -1029,17 +1007,6 @@ class PhonopySettings(Settings):
     def get_cutoff_radius(self):
         return self._cutoff_radius
 
-    def set_dos_range(self, fmin, fmax, fpitch):
-        self._fmin = fmin
-        self._fmax = fmax
-        self._fpitch = fpitch
-
-    def get_dos_range(self):
-        dos_range = {'min': self._fmin,
-                     'max': self._fmax,
-                     'step': self._fpitch}
-        return dos_range
-
     def set_fc_computation_algorithm(self, fc_computation_algorithm):
         self._fc_computation_algorithm = fc_computation_algorithm
 
@@ -1857,10 +1824,6 @@ class PhonopyConfParser(ConfParser):
         if 'write_mesh' in params:
             self._settings.set_write_mesh(params['write_mesh'])
 
-        # q-vector direction at q->0 for non-analytical term correction
-        if 'q_direction' in params:
-            self._settings.set_nac_q_direction(params['q_direction'])
-
         # Anime mode
         if 'anime_type' in params:
             self._settings.set_anime_type(params['anime_type'])
@@ -1905,8 +1868,9 @@ class PhonopyConfParser(ConfParser):
             fmin =  params['dos_range'][0]
             fmax =  params['dos_range'][1]
             fpitch = params['dos_range'][2]
-            self._settings.set_dos_range(fmin, fmax, fpitch)
-
+            self._settings.set_min_frequency(fmin)
+            self._settings.set_max_frequency(fmax)
+            self._settings.set_frequency_pitch(fpitch)
         if 'dos' in params:
             self._settings.set_is_dos_mode(params['dos'])
 
